@@ -38,7 +38,7 @@
 #' calcWINS(COVID19bHCE, ref = "Placebo", WOnull = 1.1, alpha = 0.01)
 calcWINS.hce <- function(x, ...){
   Args <- base::list(...)
-  x <- new_hce(x)
+  x <- as_hce(x)
   x <- base::as.data.frame(x)
   
   if(!is.null(Args[["ref"]])) ref <- Args[["ref"]]
