@@ -54,8 +54,8 @@ class(HCE1)
 head(HCE1)
 
 ## -----------------------------------------------------------------------------
-dat2 <- new_hce(HCE1)
-class(dat2)
+dat1 <- as_hce(HCE2)
+str(dat1)
 
 ## -----------------------------------------------------------------------------
 args("simHCE")
@@ -63,15 +63,15 @@ args("simHCE")
 ## -----------------------------------------------------------------------------
 Rates_A <- c(1.72, 1.74, 0.58, 1.5, 1) 
 Rates_P <- c(2.47, 2.24, 2.9, 4, 6) 
-dat1 <- simHCE(n = 2500, n0 = 1500, TTE_A = Rates_A, 
+dat3 <- simHCE(n = 2500, n0 = 1500, TTE_A = Rates_A, 
                TTE_P = Rates_P, 
                CM_A = -3, CM_P = -6, 
                CSD_A = 16, CSD_P = 15, 
                fixedfy = 3)
 
 ## -----------------------------------------------------------------------------
-class(dat1)
-head(dat1)
+class(dat3)
+head(dat3)
 
 ## -----------------------------------------------------------------------------
 methods(class = "hce")
